==> core-1.0.2-20161006.150320-12-sources.jar: com/imcode/imcms/addon/imagearchive/service/Facade.java <==
package com.imcode.imcms.addon.imagearchive.service;

import com.imcode.imcms.addon.imagearchive.Config;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.MessageSource;
import org.springframework.stereotype.Component;

@Component
public class Facade {
    private final Config config;
    private final UserService userService;
    private final RoleService roleService;
    private final ExifService exifService;
    private final ImcmsImageService imcmsImageService;
    private final CategoryTypeService categoryTypeService;
    private final MessageSource messageSource;
    private final FileService fileService;
    private final ImageService imageService;
    private final LibraryService libraryService;
    private final CategoryService categoryService;
    private final KeywordService keywordService;

    @Autowired
    public Facade(ImcmsImageService imcmsImageService,
                  @Qualifier("remoteImageService") ImageService imageService,
                  @Qualifier("remoteKeywordService") KeywordService keywordService,
                  @Qualifier("remoteFileService") FileService fileService,
                  @Qualifier("remoteLibraryService") LibraryService libraryService,
                  @Qualifier("remoteCategoryService") CategoryService categoryService,
                  @Qualifier("remoteExifService") ExifService exifService,
                  CategoryTypeService categoryTypeService,
                  MessageSource messageSource,
                  Config config,
                  UserService userService,
                  RoleService roleService) {

        this.imcmsImageService = imcmsImageService;
        this.imageService = imageService;
        this.keywordService = keywordService;
        this.fileService = fileService;
        this.libraryService = libraryService;
        this.categoryService = categoryService;
        this.categoryTypeService = categoryTypeService;
        this.messageSource = messageSource;
        this.exifService = exifService;
        this.config = config;
        this.userService = userService;
        this.roleService = roleService;
    }

    public ExifService getExifService() {
        return exifService;
    }

    public Config getConfig() {
        return config;
    }

    public FileService getFileService() {
        return fileService;
    }

    public ImageService getImageService() {
        return imageService;
    }

    public LibraryService getLibraryService() {
        return libraryService;
    }

    public CategoryService getCategoryService() {
        return categoryService;
    }

    public KeywordService getKeywordService() {
        return keywordService;
    }

    public RoleService getRoleService() {
        return roleService;
    }

    public UserService getUserService() {
        return userService;
    }

    public ImcmsImageService getImcmsImageService() {
        return imcmsImageService;
    }

    public MessageSource getMessageSource() {
        return messageSource;
    }

    public CategoryTypeService getCategoryTypeService() {
        return categoryTypeService;
    }
}

==> core-1.0.2-20161007.084436-13-sources.jar: com/imcode/imcms/addon/imagearchive/service/Facade.java <==
package com.imcode.imcms.addon.imagearchive.service;

import com.imcode.imcms.addon.imagearchive.Config;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.MessageSource;
import org.springframework.stereotype.Component;

@Component
public class Facade {
    private final Config config;
    private final UserService userService;
    private final RoleService roleService;
    private final ExifService exifService;
    private final ImcmsImageService imcmsImageService;
    private final CategoryTypeService categoryTypeService;
    private final MessageSource messageSource;
    private final FileService fileService;
    private final ImageService imageService;
    private final LibraryService libraryService;
    private final CategoryService categoryService;
    private final KeywordService keywordService;

    @Autowired
    public Facade(ImcmsImageService imcmsImageService,
                  @Qualifier("remoteImageService") ImageService imageService,
                  @Qualifier("remoteKeywordService") KeywordService keywordService,
                  @Qualifier("remoteFileService") FileService fileService,
                  @Qualifier("remoteLibraryService") LibraryService libraryService,
                  @Qualifier("remoteCategoryService") CategoryService categoryService,
                  @Qualifier("remoteCategoryTypeService") CategoryTypeService categoryTypeService,
                  @Qualifier("remoteExifService") ExifService exifService,
                  @Qualifier("remoteUserService") UserService userService,
                  @Qualifier("remoteRoleService") RoleService roleService,
                  MessageSource messageSource,
                  Config config) {

        this.imcmsImageService = imcmsImageService;
        this.imageService = imageService;
        this.keywordService = keywordService;
        this.fileService = fileService;
        this.libraryService = libraryService;
        this.categoryService = categoryService;
        this.categoryTypeService = categoryTypeService;
        this.messageSource = messageSource;
        this.exifService = exifService;
        this.config = config;
        this.userService = userService;
        this.roleService = roleService;
    }

    public ExifService getExifService() {
        return exifService;
    }

    public Config getConfig() {
        return config;
    }

    public FileService getFileService() {
        return fileService;
    }

    public ImageService getImageService() {
        return imageService;
    }

    public LibraryService getLibraryService() {
        return libraryService;
    }

    public CategoryService getCategoryService() {
        return categoryService;
    }

    public KeywordService getKeywordService() {
        return keywordService;
    }

    public RoleService getRoleService() {
        return roleService;
    }

    public UserService getUserService() {
        return userService;
    }

    public ImcmsImageService getImcmsImageService() {
        return imcmsImageService;
    }

    public MessageSource getMessageSource() {
        return messageSource;
    }

    public CategoryTypeService getCategoryTypeService() {
        return categoryTypeService;
    }
}
